read_inline

Function read_inline 

pub fn read_inline(
    interp: &mut Interp<'_>,
    ctx: &Context,
    elems: &[IText],
    env: &Env,
) -> Result<Vec<HorzBox>, EvalError>
Convert quoted inline text to boxes under ctx (the core of read-inline): words become measured InnerStrings, whitespace becomes glue, embedded commands are applied to ctx and their arguments.