pub struct TypeContext { /* private fields */ }Expand description
Per-inference-run state: the level stack for generalization, and a
counter for fresh variable ids (see FRESH_ID’s doc comment for why
instantiate/unify use a different counter than this one — the two
never need to agree, since identity is always by pointer).
Implementations
Sourceimpl TypeContext
impl TypeContext
pub fn new() -> Self
pub fn level(&self) -> u32
Sourcepub fn enter_level(&mut self)
pub fn enter_level(&mut self)
Enter a new let-nesting level. Call before inferring the
right-hand side of a let.
Sourcepub fn leave_level(&mut self)
pub fn leave_level(&mut self)
Leave the current level. Call after inferring the right-hand side
of a let, before calling generalize.
pub fn fresh_var(&mut self) -> TyVarRef
pub fn fresh_var_with_kind(&mut self, kind: Kind) -> TyVarRef
pub fn fresh_row_var(&mut self) -> RowVarRef
pub fn fresh_row_var_with_kind(&mut self, kind: BTreeSet<String>) -> RowVarRef